@@ -16,13 +16,21 @@ from django_upgrade.tokens import update_import_modules
 
 fixer = Fixer(
     __name__,
-    min_version=(1, 9),
+    min_version=(1, 11),
 )
 
 REWRITES = {
-    "django.forms.forms": {
-        "pretty_name": "django.forms.utils",
-        "BoundField": "django.forms.boundfield",
+    "django.db.models.fields": {
+        "FieldDoesNotExist": "django.core.exceptions",
+    },
+    "django.db.models.query": {
+        "EmptyResultSet": "django.core.exceptions",
+    },
+    "django.db.models.sql": {
+        "EmptyResultSet": "django.core.exceptions",
+    },
+    "django.db.models.sql.datastructures": {
+        "EmptyResultSet": "django.core.exceptions",
     },
 }
 
