@@ -17,6 +17,7 @@ from django_upgrade.compat import str_removeprefix
 from django_upgrade.data import Fixer, State, TokenFunc
 from django_upgrade.tokens import (
     STRING,
+    erase_node,
     extract_indent,
     find,
     insert,
@@ -42,7 +43,17 @@ def visit_ImportFrom(
         and any(alias.name in ("include", "url") for alias in node.names)
     ):
         yield ast_start_offset(node), partial(
-            update_import,
+            update_django_conf_import,
+            node=node,
+            state=state,
+        )
+    elif (
+        node.module == "django.urls"
+        and is_rewritable_import_from(node)
+        and any(alias.name == "re_path" for alias in node.names)
+    ):
+        yield ast_start_offset(node), partial(
+            update_django_urls_import,
             node=node,
             state=state,
         )
@@ -54,23 +65,18 @@ def visit_ImportFrom(
 state_used_names: MutableMapping[State, set[str]] = WeakKeyDictionary()
 
 
-def update_import(
+def update_django_conf_import(
     tokens: list[Token], i: int, *, node: ast.ImportFrom, state: State
 ) -> None:
-    """ """
-    removals = set()
-    additions = set()
+    re_path_imported = "re_path" in state.from_imports["django.urls"]
     used_names = state_used_names.pop(state, set())
+    removals = set()
 
     for alias in node.names:
         if alias.asname is not None:
             continue
-        if alias.name == "include":
-            removals.add("include")
-            additions.add("include")
-        elif alias.name == "url" and used_names:
-            removals.add("url")
-            additions.update(used_names)
+        if alias.name in ("include", "url") and (used_names or re_path_imported):
+            removals.add(alias.name)
 
     if removals:
         j, indent = extract_indent(tokens, i)
@@ -80,7 +86,29 @@ def update_import(
             node=node,
             name_map={name: "" for name in removals},
         )
-        joined_names = ", ".join(sorted(additions))
+        if not re_path_imported:
+            joined_names = ", ".join(sorted(used_names))
+            insert(
+                tokens,
+                j,
+                new_src=f"{indent}from django.urls import {joined_names}\n",
+            )
+        else:
+            state_used_names[state] = used_names
+
+
+def update_django_urls_import(
+    tokens: list[Token], i: int, *, node: ast.ImportFrom, state: State
+) -> None:
+    used_names = state_used_names.pop(state, set())
+
+    if used_names:
+        initial_names = state.from_imports["django.urls"] - {"re_path"}
+        used_names.update(initial_names)
+
+        j, indent = extract_indent(tokens, i)
+        erase_node(tokens, i, node=node)
+        joined_names = ", ".join(sorted(used_names))
         insert(
             tokens,
             j,
@@ -96,8 +124,13 @@ def visit_Call(
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         isinstance(node.func, ast.Name)
-        and node.func.id == "url"
-        and "url" in state.from_imports["django.conf.urls"]
+        and (
+            (node.func.id == "url" and "url" in state.from_imports["django.conf.urls"])
+            or (
+                node.func.id == "re_path"
+                and "re_path" in state.from_imports["django.urls"]
+            )
+        )
         # cannot convert where called with all kwargs as names don't align
         and len(node.args) >= 1
     ):
@@ -113,6 +146,13 @@ def visit_Call(
             state=state,
         )
 
+    if (
+        isinstance(node.func, ast.Name)
+        and node.func.id == "include"
+        and "include" in state.from_imports["django.conf.urls"]
+    ):
+        state_used_names.setdefault(state, set()).add("include")
+
 
 def fix_url_call(
     tokens: list[Token], i: int, *, regex_path: str | None, state: State
