@@ -2,9 +2,11 @@
 Replace imports from django.utils.translation:
 https://docs.djangoproject.com/en/3.0/releases/3.0/#features-deprecated-in-3-0
 """
+from __future__ import annotations
+
 import ast
 from functools import partial
-from typing import Iterable, List, Tuple
+from typing import Iterable
 
 from tokenize_rt import Offset, Token
 
@@ -34,7 +36,7 @@ def visit_ImportFrom(
     state: State,
     node: ast.ImportFrom,
     parent: ast.AST,
-) -> Iterable[Tuple[Offset, TokenFunc]]:
+) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         node.level == 0
         and node.module == MODULE
@@ -45,7 +47,7 @@ def visit_ImportFrom(
         yield ast_start_offset(node), partial(fix_import, node=node)
 
 
-def fix_import(tokens: List[Token], i: int, *, node: ast.ImportFrom) -> None:
+def fix_import(tokens: list[Token], i: int, *, node: ast.ImportFrom) -> None:
     j, indent = extract_indent(tokens, i)
     update_import_names(tokens, i, node=node, name_map={OLD_NAME: ""})
     insert(tokens, j, new_src=f"{indent}import html\n")
@@ -56,7 +58,7 @@ def visit_Name(
     state: State,
     node: ast.Name,
     parent: ast.AST,
-) -> Iterable[Tuple[Offset, TokenFunc]]:
+) -> Iterable[tuple[Offset, TokenFunc]]:
     if node.id == OLD_NAME and OLD_NAME in state.from_imports[MODULE]:
         yield ast_start_offset(node), partial(
             find_and_replace_name, name=OLD_NAME, new="html.escape"
